import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import { memo as _$memo } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { useTransformNamePolicy } from "@typespec/emitter-framework";
import { getDefaultValue } from "../utils/parameters.js";
import { JsonTransform } from "./transforms/json/json-transform.js";
export function HttpRequestParametersExpression(props) {
  const parameters = [];
  const transformNamer = useTransformNamePolicy();
  if (props.children || Array.isArray(props.children) && props.children.length) {
    parameters.push([_$memo(() => props.children), ","]);
  }
  if (!props.parameters && parameters.length) {
    return _$createComponent(ts.ObjectExpression, {
      children: parameters
    });
  } else if (!props.parameters) {
    return _$createComponent(ts.ObjectExpression, {});
  }
  const optionsParamRef = props.optionsParameter ?? "options";
  const members = _$createComponent(ay.For, {
    get each() {
      return props.parameters;
    },
    line: true,
    comma: true,
    children: httpProperty => {
      const parameter = httpProperty.property;
      const defaultValue = getDefaultValue(httpProperty);
      const paramItemRef = transformNamer.getApplicationName(parameter);
      const paramRef = ay.code`${optionsParamRef}?.${paramItemRef}`;
      if (defaultValue) {
        const defaultAssignment = defaultValue ? ` ?? ${defaultValue}` : "";
        const headerValue = [paramRef, defaultAssignment];
        const name = transformNamer.getTransportName(parameter);
        const paramAssignment = _$createComponent(ts.ObjectProperty, {
          name: `"${name}"`,
          value: headerValue
        });
        return paramAssignment;
      }
      const itemRef = parameter.optional ? ay.code`${optionsParamRef}?` : null;
      if (parameter.optional) {
        return ay.code`
        ...(${paramRef} && {${_$createComponent(JsonTransform, {
          itemRef: itemRef,
          type: parameter,
          target: "transport"
        })}})
      `;
      } else {
        return _$createComponent(JsonTransform, {
          itemRef: itemRef,
          type: parameter,
          target: "transport"
        });
      }
    }
  });
  parameters.push(members);
  return _$createComponent(ts.ObjectExpression, {
    children: parameters
  });
}
//# sourceMappingURL=http-request-parameters-expression.js.map