import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import { memo as _$memo } from "@alloy-js/core/jsx-runtime";
import * as ts from "@alloy-js/typescript";
import { $ } from "@typespec/compiler/experimental/typekit";
import { DateDeserializer, DateRfc3339Serializer, DateRfc7231Deserializer, DateRfc7231Serializer, DateUnixTimestampDeserializer, DateUnixTimestampSerializer } from "@typespec/emitter-framework/typescript";
import { useClientLibrary } from "@typespec/http-client";
import { flattenClients } from "../utils/client-discovery.js";
import { EncodingProvider } from "./encoding-provider.js";
import { DecodeBase64, EncodeUint8Array } from "./static-helpers/bytes-encoding.js";
import { JsonTransformDeclaration } from "./transforms/json/json-transform.js";
import { TransformDeclaration } from "./transforms/operation-transform-declaration.js";
export function ModelSerializers(props) {
  const clientLibrary = useClientLibrary();
  const dataTypes = clientLibrary.dataTypes;
  const flatClients = clientLibrary.topLevel.flatMap(c => flattenClients(c));
  const operations = flatClients.flatMap(c => c.operations);
  // Todo: Handle other kinds of serialization, for example XML. Might need to
  // revisit the way we process these and might need to track the relationship
  // between the data type and the operations that consume them.
  return _$createComponent(ts.SourceFile, {
    get path() {
      return props.path ?? "serializers.ts";
    },
    get children() {
      return [_$createComponent(DecodeBase64, {}), _$createComponent(EncodeUint8Array, {}), _$createComponent(DateDeserializer, {}), _$createComponent(DateRfc7231Deserializer, {}), _$createComponent(DateRfc3339Serializer, {}), _$createComponent(DateRfc7231Serializer, {}), _$createComponent(DateUnixTimestampSerializer, {}), _$createComponent(DateUnixTimestampDeserializer, {}), _$memo(() => operations.map(o => _$createComponent(TransformDeclaration, {
        operation: o
      }))), _$memo(() => dataTypes.filter(m => m.kind === "Model" || m.kind === "Union").map(type => {
        let bytesDefaultEncoding = "base64";
        if ($.model.is(type) && type.baseModel && $.model.isHttpFile(type.baseModel)) {
          bytesDefaultEncoding = "none";
        }
        return _$createComponent(EncodingProvider, {
          defaults: {
            bytes: bytesDefaultEncoding
          },
          get children() {
            return [_$createComponent(JsonTransformDeclaration, {
              type: type,
              target: "transport"
            }), _$createComponent(JsonTransformDeclaration, {
              type: type,
              target: "application"
            })];
          }
        });
      }))];
    }
  });
}
//# sourceMappingURL=serializers.js.map