import { memo as _$memo } from "@alloy-js/core/jsx-runtime";
import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { $ } from "@typespec/compiler/experimental/typekit";
import { getJsonRecordTransformRefkey } from "./json-record-transform.js";
export function JsonAdditionalPropertiesTransform(props) {
  const additionalProperties = $.model.getAdditionalPropertiesRecord(props.type);
  if (!additionalProperties) {
    return null;
  }
  if (props.target === "application") {
    const properties = $.model.getProperties(props.type, {
      includeExtended: true
    });
    const destructuredProperties = ay.mapJoin(() => properties, name => name, {
      joiner: ",",
      ender: ","
    });

    // Inline destructuring that extracts the properties and passes the rest to jsonRecordUnknownToApplicationTransform_2
    const inlineDestructure = ay.code`
    ${getJsonRecordTransformRefkey(additionalProperties, props.target)}(
      (({ ${destructuredProperties} ...rest }) => rest)(${props.itemRef})
    ),
    `;
    return [_$createComponent(ts.ObjectProperty, {
      name: "additionalProperties",
      children: inlineDestructure
    })];
  }
  const itemRef = ay.code`${props.itemRef}.additionalProperties`;
  return ["...(", _$memo(() => getJsonRecordTransformRefkey(additionalProperties, props.target)), "(", itemRef, ") ),"];
}
//# sourceMappingURL=json-model-additional-properties-transform.js.map