import { mergeProps as _$mergeProps } from "@alloy-js/core/jsx-runtime";
import { memo as _$memo } from "@alloy-js/core/jsx-runtime";
import { createComponent as _$createComponent } from "@alloy-js/core/jsx-runtime";
import * as ay from "@alloy-js/core";
import * as ts from "@alloy-js/typescript";
import { $ } from "@typespec/compiler/experimental/typekit";
import { JsonAdditionalPropertiesTransform } from "./json-model-additional-properties-transform.js";
import { JsonModelPropertyTransform } from "./json-model-property-transform.js";
import { JsonRecordTransformDeclaration } from "./json-record-transform.js";
import { getJsonTransformDiscriminatorRefkey, JsonTransformDiscriminatorDeclaration } from "./json-transform-discriminator.js";
export function JsonModelTransform(props) {
  // Need to skip never properties
  const properties = Array.from($.model.getProperties(props.type, {
    includeExtended: true
  }).values()).filter(p => !$.type.isNever(p.type));
  const discriminator = $.type.getDiscriminator(props.type);
  const discriminate = getJsonTransformDiscriminatorRefkey(props.type, props.target);
  return _$createComponent(ts.ObjectExpression, {
    get children() {
      return [_$createComponent(JsonAdditionalPropertiesTransform, {
        get itemRef() {
          return props.itemRef;
        },
        get target() {
          return props.target;
        },
        get type() {
          return props.type;
        }
      }), _$memo(() => discriminator ? ["...", discriminate, "(", _$memo(() => props.itemRef), "),"] : null), _$createComponent(ay.For, {
        each: properties,
        joiner: ",",
        line: true,
        children: property => {
          return _$createComponent(JsonModelPropertyTransform, {
            get itemRef() {
              return props.itemRef;
            },
            type: property,
            get target() {
              return props.target;
            }
          });
        }
      })];
    }
  });
}
export function getJsonModelTransformRefkey(type, target) {
  return ay.refkey(type, "json_model_transform", target);
}
export function JsonModelTransformDeclaration(props) {
  const namePolicy = ts.useTSNamePolicy();
  const transformName = namePolicy.getName(`json_${props.type.name}_to_${props.target}_transform`, "function");
  const returnType = props.target === "transport" ? "any" : ay.refkey(props.type);
  const inputType = props.target === "transport" ? [_$memo(() => ay.refkey(props.type)), " | null"] : "any";
  const inputRef = ay.refkey();
  const parameters = {
    // Make the input optional to make the transform more robust and check against null and undefined
    input_: {
      type: inputType,
      refkey: inputRef,
      optional: true
    }
  };
  const spread = $.model.getSpreadType(props.type);
  const hasAdditionalProperties = spread && $.model.is(spread) && $.record.is(spread);
  const declarationRefkey = getJsonModelTransformRefkey(props.type, props.target);
  return [hasAdditionalProperties ? _$createComponent(JsonRecordTransformDeclaration, {
    get target() {
      return props.target;
    },
    type: spread
  }) : null, _$createComponent(JsonTransformDiscriminatorDeclaration, {
    get type() {
      return props.type;
    },
    get target() {
      return props.target;
    }
  }), _$createComponent(ts.FunctionDeclaration, {
    name: transformName,
    "export": true,
    returnType: returnType,
    parameters: parameters,
    refkey: declarationRefkey,
    get children() {
      return [_$memo(() => ay.code`
      if(!${inputRef}) {
        return ${inputRef} as any;
      }
        
      `), "return ", _$createComponent(JsonModelTransform, _$mergeProps(props, {
        itemRef: inputRef
      })), "!;"];
    }
  })];
}
//# sourceMappingURL=json-model-transform.js.map